@@ -4,16 +4,15 @@ void IntegrityScanner::testExitValue(std::string const &cmd,
                             std::string const &exitStr)
 {
     if (not (s_exitValue << exitStr))
-        d_stealthLog << "No exit value for\n" <<
+        fmsg << "No exit value for\n" <<
             cmd << "\n"
-            "NOTE: this is the literal text of the executed command. "
-                            "Maybe a typo?" << RunMode::leave;
+            "ADVICE: this is the literal text of the executed command. "
+                                                     "Maybe a typo?" << noidl;
 
     if (d_testExitValue && stoul(s_exitValue[1]) != 0)
-        d_stealthLog << 
-            d_options.basename() << 
+        fmsg << d_options.basename() << 
                                 " terminated: non-zero exit value for\n" <<
-            *d_cmdIterator << " (" << exitStr << ")" << RunMode::leave;
+                *d_cmdIterator << " (" << exitStr << ")" << noidl;
 }
 
 
