@@ -7,8 +7,7 @@ void IntegrityScanner::write(string const &fname)
     ifstream source(fname.c_str());
 
     if (!source)
-        d_stealthLog << "Can't open `" << fname << "' to read." <<
-                                                        StealthEnums::leave; 
+       fmsg << "can't read `" << fname << '\'' << noidl; 
 
     m3 << "about to read local `" << fname << '\'' << endl;
 
@@ -23,7 +22,7 @@ void IntegrityScanner::write(string const &fname)
             break;
 
         if (!d_sshFork.write(buffer, nRead))
-            d_stealthLog << "PUT failed." << StealthEnums::leave;
+            fmsg << "PUT failed." << noidl;
     }
 
     d_sshFork.flush();
