@@ -1,7 +1,5 @@
 #include "stealth.ih"
 
 void Stealth::parentProcess()
-{
-    d_ipc.writeRunFile(pid());
-}
+{}
 
